@@ -3,7 +3,7 @@ use {
         erasure::ErasureConfig,
         shred::{Shred, ShredType},
     },
-    serde::{Deserialize, Serialize},
+    serde::{Deserialize, Deserializer, Serialize, Serializer},
     solana_sdk::{clock::Slot, hash::Hash},
     std::{
         collections::BTreeSet,
@@ -27,9 +27,13 @@ pub struct SlotMeta {
     // The timestamp of the first time a shred was added for this slot
     pub first_shred_timestamp: u64,
     // The index of the shred that is flagged as the last shred for this slot.
-    pub last_index: u64,
+    // None until the shred with LAST_SHRED_IN_SLOT flag is received.
+    #[serde(with = "serde_compat")]
+    pub last_index: Option<u64>,
     // The slot height of the block this one derives from.
-    pub parent_slot: Slot,
+    // The parent slot of the head of a detached chain of slots is None.
+    #[serde(with = "serde_compat")]
+    pub parent_slot: Option<Slot>,
     // The list of slots, each of which contains a block that derives
     // from this one.
     pub next_slots: Vec<Slot>,
@@ -40,6 +44,27 @@ pub struct SlotMeta {
     pub completed_data_indexes: BTreeSet<u32>,
 }
 
+// Serde implementation of serialize and deserialize for Option<u64>
+// where None is represented as u64::MAX; for backward compatibility.
+mod serde_compat {
+    use super::*;
+
+    pub(super) fn serialize<S>(val: &Option<u64>, serializer: S) -> Result<S::Ok, S::Error>
+    where
+        S: Serializer,
+    {
+        val.unwrap_or(u64::MAX).serialize(serializer)
+    }
+
+    pub(super) fn deserialize<'de, D>(deserializer: D) -> Result<Option<u64>, D::Error>
+    where
+        D: Deserializer<'de>,
+    {
+        let val = u64::deserialize(deserializer)?;
+        Ok((val != u64::MAX).then(|| val))
+    }
+}
+
 #[derive(Clone, Debug, Default, Deserialize, Serialize, PartialEq)]
 /// Index recording presence/absence of shreds
 pub struct Index {
@@ -126,10 +151,10 @@ impl Index {
         &self.coding
     }
 
-    pub fn data_mut(&mut self) -> &mut ShredIndex {
+    pub(crate) fn data_mut(&mut self) -> &mut ShredIndex {
         &mut self.data
     }
-    pub fn coding_mut(&mut self) -> &mut ShredIndex {
+    pub(crate) fn coding_mut(&mut self) -> &mut ShredIndex {
         &mut self.coding
     }
 }
@@ -139,71 +164,48 @@ impl ShredIndex {
         self.index.len()
     }
 
-    pub fn present_in_bounds(&self, bounds: impl RangeBounds<u64>) -> usize {
-        self.index.range(bounds).count()
+    pub(crate) fn range<R>(&self, bounds: R) -> impl Iterator<Item = &u64>
+    where
+        R: RangeBounds<u64>,
+    {
+        self.index.range(bounds)
     }
 
-    pub fn is_present(&self, index: u64) -> bool {
+    pub(crate) fn contains(&self, index: u64) -> bool {
         self.index.contains(&index)
     }
 
-    pub fn set_present(&mut self, index: u64, presence: bool) {
-        if presence {
-            self.index.insert(index);
-        } else {
-            self.index.remove(&index);
-        }
-    }
-
-    pub fn set_many_present(&mut self, presence: impl IntoIterator<Item = (u64, bool)>) {
-        for (idx, present) in presence.into_iter() {
-            self.set_present(idx, present);
-        }
-    }
-
-    pub fn largest(&self) -> Option<u64> {
-        self.index.iter().rev().next().copied()
+    pub(crate) fn insert(&mut self, index: u64) {
+        self.index.insert(index);
     }
 }
 
 impl SlotMeta {
     pub fn is_full(&self) -> bool {
-        // last_index is std::u64::MAX when it has no information about how
+        // last_index is None when it has no information about how
         // many shreds will fill this slot.
         // Note: A full slot with zero shreds is not possible.
-        if self.last_index == std::u64::MAX {
-            return false;
-        }
-
         // Should never happen
-        if self.consumed > self.last_index + 1 {
+        if self
+            .last_index
+            .map(|ix| self.consumed > ix + 1)
+            .unwrap_or_default()
+        {
             datapoint_error!(
                 "blockstore_error",
                 (
                     "error",
                     format!(
-                        "Observed a slot meta with consumed: {} > meta.last_index + 1: {}",
+                        "Observed a slot meta with consumed: {} > meta.last_index + 1: {:?}",
                         self.consumed,
-                        self.last_index + 1
+                        self.last_index.map(|ix| ix + 1),
                     ),
                     String
                 )
             );
         }
 
-        self.consumed == self.last_index + 1
-    }
-
-    pub fn known_last_index(&self) -> Option<u64> {
-        if self.last_index == std::u64::MAX {
-            None
-        } else {
-            Some(self.last_index)
-        }
-    }
-
-    pub fn is_parent_set(&self) -> bool {
-        self.parent_slot != std::u64::MAX
+        Some(self.consumed) == self.last_index.map(|ix| ix + 1)
     }
 
     pub fn clear_unconfirmed_slot(&mut self) {
@@ -212,18 +214,17 @@ impl SlotMeta {
         std::mem::swap(self, &mut new_self);
     }
 
-    pub(crate) fn new(slot: Slot, parent_slot: Slot) -> Self {
+    pub(crate) fn new(slot: Slot, parent_slot: Option<Slot>) -> Self {
         SlotMeta {
             slot,
             parent_slot,
             is_connected: slot == 0,
-            last_index: std::u64::MAX,
             ..SlotMeta::default()
         }
     }
 
     pub(crate) fn new_orphan(slot: Slot) -> Self {
-        Self::new(slot, std::u64::MAX)
+        Self::new(slot, /*parent_slot:*/ None)
     }
 }
 
@@ -289,10 +290,8 @@ impl ErasureMeta {
     pub(crate) fn status(&self, index: &Index) -> ErasureMetaStatus {
         use ErasureMetaStatus::*;
 
-        let num_coding = index
-            .coding()
-            .present_in_bounds(self.coding_shreds_indices());
-        let num_data = index.data().present_in_bounds(self.data_shreds_indices());
+        let num_coding = index.coding().range(self.coding_shreds_indices()).count();
+        let num_data = index.data().range(self.data_shreds_indices()).count();
 
         let (data_missing, num_needed) = (
             self.config.num_data().saturating_sub(num_data),
@@ -343,7 +342,6 @@ mod test {
     use {
         super::*,
         rand::{seq::SliceRandom, thread_rng},
-        std::iter::repeat,
     };
 
     #[test]
@@ -367,35 +365,35 @@ mod test {
 
         assert_eq!(e_meta.status(&index), StillNeed(erasure_config.num_data()));
 
-        index
-            .data_mut()
-            .set_many_present(data_indexes.clone().zip(repeat(true)));
+        for ix in data_indexes.clone() {
+            index.data_mut().insert(ix);
+        }
 
         assert_eq!(e_meta.status(&index), DataFull);
 
-        index
-            .coding_mut()
-            .set_many_present(coding_indexes.clone().zip(repeat(true)));
+        for ix in coding_indexes.clone() {
+            index.coding_mut().insert(ix);
+        }
 
         for &idx in data_indexes
             .clone()
             .collect::<Vec<_>>()
             .choose_multiple(&mut rng, erasure_config.num_data())
         {
-            index.data_mut().set_present(idx, false);
+            index.data_mut().index.remove(&idx);
 
             assert_eq!(e_meta.status(&index), CanRecover);
         }
 
-        index
-            .data_mut()
-            .set_many_present(data_indexes.zip(repeat(true)));
+        for ix in data_indexes {
+            index.data_mut().insert(ix);
+        }
 
         for &idx in coding_indexes
             .collect::<Vec<_>>()
             .choose_multiple(&mut rng, erasure_config.num_coding())
         {
-            index.coding_mut().set_present(idx, false);
+            index.coding_mut().index.remove(&idx);
 
             assert_eq!(e_meta.status(&index), DataFull);
         }
